@@ -34,6 +34,10 @@ Options:
                     DATE should be in the future
   --peertubeAt=DATE
   --youtubeAt=DATE  Override publishAt for the corresponding platform. Allow to create preview on specific platform
+  --originalDate=DATE  Configure the video as initially recorded at DATE
+                        DATE should be on the form YYYY-MM-DDThh:mm:ss eg: 2018-03-12T19:00:00
+                        DATE should be in the past
+  --auto-originalDate     Automatically use the file modification time as original date
   --thumbnail=STRING    Path to a file to use as a thumbnail for the video.
                         Supported types are jpg and jpeg.
                         By default, prismedia search for an image based on video name followed by .jpg or .jpeg
@@ -45,6 +49,7 @@ Options:
                     If the playlist is not found, spawn an error except if --playlistCreate is set.
   --playlistCreate  Create the playlist if not exists. (default do not create)
                     Only relevant if --playlist is set.
+  --progress=STRING Set the progress bar view, one of percentage, bigFile (MB), accurate (KB).
   -h --help  Show this help.
   --version  Show version.
 
@@ -71,6 +76,7 @@ Strict options:
   --withTags        Prevent the upload without tags
   --withPlaylist    Prevent the upload if no playlist
   --withPublishAt    Prevent the upload if no schedule
+  --withOriginalDate    Prevent the upload if no original date configured
   --withPlatform    Prevent the upload if at least one platform is not specified
   --withCategory    Prevent the upload if no category
   --withLanguage    Prevent upload if no language
@@ -130,7 +136,7 @@ except ImportError:
                   'see https://github.com/ahupp/python-magic\n')
     exit(1)
 
-VERSION = "prismedia v0.10.3"
+VERSION = "prismedia v0.11.0"
 
 VALID_PRIVACY_STATUSES = ('public', 'private', 'unlisted')
 VALID_CATEGORIES = (
@@ -145,6 +151,7 @@ VALID_LANGUAGES = ('arabic', 'english', 'french',
                    'german', 'hindi', 'italian',
                    'japanese', 'korean', 'mandarin',
                    'portuguese', 'punjabi', 'russian', 'spanish')
+VALID_PROGRESS = ('percentage', 'bigfile', 'accurate')
 
 
 def validateVideo(path):
@@ -190,11 +197,11 @@ def validateLanguage(language):
         return False
 
 
-def validatePublish(publish):
+def validatePublishDate(publishDate):
     # Check date format and if date is future
     try:
         now = datetime.datetime.now()
-        publishAt = datetime.datetime.strptime(publish, '%Y-%m-%dT%H:%M:%S')
+        publishAt = datetime.datetime.strptime(publishDate, '%Y-%m-%dT%H:%M:%S')
         if now >= publishAt:
             return False
     except ValueError:
@@ -202,6 +209,18 @@ def validatePublish(publish):
     return True
 
 
+def validateOriginalDate(originalDate):
+    # Check date format and if date is past
+    try:
+        now = datetime.datetime.now()
+        originalDate = datetime.datetime.strptime(originalDate, '%Y-%m-%dT%H:%M:%S')
+        if now <= originalDate:
+            return False
+    except ValueError:
+        return False
+    return True
+
+
 def validateThumbnail(thumbnail):
     supported_types = ['image/jpg', 'image/jpeg']
     if os.path.exists(thumbnail) and \
@@ -217,6 +236,15 @@ def validateLogLevel(loglevel):
         return False
     return True
 
+
+def validateProgress(progress):
+    for prgs in progress.split(','):
+        if prgs.lower().replace(" ", "") not in VALID_PROGRESS:
+            return False
+
+    return True
+
+
 def _optionnalOrStrict(key, scope, error):
     option = key.replace('-', '')
     option = option[0].upper() + option[1:]
@@ -280,6 +308,7 @@ def main():
         Optional('--withTags', default=False): bool,
         Optional('--withPlaylist', default=False): bool,
         Optional('--withPublishAt', default=False): bool,
+        Optional('--withOriginalDate', default=False): bool,
         Optional('--withPlatform', default=False): bool,
         Optional('--withCategory', default=False): bool,
         Optional('--withLanguage', default=False): bool,
@@ -298,6 +327,7 @@ def main():
         Hook('--language', handler=_optionnalOrStrict): object,
         Hook('--platform', handler=_optionnalOrStrict): object,
         Hook('--publishAt', handler=_optionnalOrStrict): object,
+        Hook('--originalDate', handler=_optionnalOrStrict): object,
         Hook('--thumbnail', handler=_optionnalOrStrict): object,
         Hook('--channel', handler=_optionnalOrStrict): object,
         Hook('--playlist', handler=_optionnalOrStrict): object,
@@ -336,19 +366,25 @@ def main():
         Optional('--platform'): Or(None, And(str, validatePlatform, error="Sorry, upload platform not supported")),
         Optional('--publishAt'): Or(None, And(
                                     str,
-                                    validatePublish,
-                                    error="DATE should be the form YYYY-MM-DDThh:mm:ss and has to be in the future")
+                                    validatePublishDate,
+                                    error="Publish Date should be the form YYYY-MM-DDThh:mm:ss and has to be in the future")
                                     ),
         Optional('--peertubeAt'): Or(None, And(
                                     str,
-                                    validatePublish,
-                                    error="DATE should be the form YYYY-MM-DDThh:mm:ss and has to be in the future")
+                                    validatePublishDate,
+                                    error="Publish Date should be the form YYYY-MM-DDThh:mm:ss and has to be in the future")
                                     ),
         Optional('--youtubeAt'): Or(None, And(
                                     str,
-                                    validatePublish,
-                                    error="DATE should be the form YYYY-MM-DDThh:mm:ss and has to be in the future")
+                                    validatePublishDate,
+                                    error="Publish Date should be the form YYYY-MM-DDThh:mm:ss and has to be in the future")
                                     ),
+        Optional('--originalDate'): Or(None, And(
+                                    str,
+                                    validateOriginalDate,
+                                    error="Original date should be the form YYYY-MM-DDThh:mm:ss and has to be in the past")
+                                    ),
+        Optional('--auto-originalDate'): bool,
         Optional('--cca'): bool,
         Optional('--disable-comments'): bool,
         Optional('--nsfw'): bool,
@@ -359,6 +395,7 @@ def main():
         Optional('--channelCreate'): bool,
         Optional('--playlist'): Or(None, str),
         Optional('--playlistCreate'): bool,
+        Optional('--progress'): Or(None, And(str, validateProgress, error="Sorry, progress visualisation not supported")),
         '--help': bool,
         '--version': bool,
         # This allow to return all other options for further use: https://github.com/keleshev/schema#extra-keys
@@ -377,6 +414,12 @@ def main():
 
     options = utils.parseNFO(options)
 
+    # If after loading NFO we still has no original date and --auto-originalDate is enabled,
+    # then we need to search from the file
+    # We need to do that before the strict validation in case --withOriginalDate is enabled
+    if not options.get('--originalDate') and options.get('--auto-originalDate'):
+        options['--originalDate'] = utils.searchOriginalDate(options)
+
     # Once NFO are loaded, we need to revalidate strict options in case some were in NFO
     try:
         options = earlyoptionSchema.validate(options)
