@@ -89,6 +89,15 @@ def check_authenticated_scopes():
                 os.remove(CREDENTIALS_PATH)
 
 
+def convert_youtube_date(date):
+    # Youtube needs microsecond and the local timezone from ISO 8601
+    date = date + ".000001"
+    date = datetime.datetime.strptime(date, '%Y-%m-%dT%H:%M:%S.%f')
+    tz = get_localzone()
+    tz = pytz.timezone(str(tz))
+    return tz.localize(date).isoformat()
+
+
 def initialize_upload(youtube, options):
     path = options.get('--file')
     tags = None
@@ -107,6 +116,8 @@ def initialize_upload(youtube, options):
     if options.get('--cca'):
         license = "creativeCommon"
 
+    # We set recordingDetails empty because it's easier to add options if it already exists
+    # and if empty, it does not cause problem during upload
     body = {
         "snippet": {
             "title": options.get('--name') or splitext(basename(path))[0],
@@ -119,6 +130,9 @@ def initialize_upload(youtube, options):
         "status": {
             "privacyStatus": str(options.get('--privacy') or "private"),
             "license": str(license or "youtube"),
+        },
+        "recordingDetails": {
+
         }
     }
 
@@ -128,15 +142,16 @@ def initialize_upload(youtube, options):
     elif options.get('--publishAt'):
         publishAt = options.get('--publishAt')
 
+    # Check if publishAt variable exists in local variables
     if 'publishAt' in locals():
-        # Youtube needs microsecond and the local timezone from ISO 8601
-        publishAt = publishAt + ".000001"
-        publishAt = datetime.datetime.strptime(publishAt, '%Y-%m-%dT%H:%M:%S.%f')
-        tz = get_localzone()
-        tz = pytz.timezone(str(tz))
-        publishAt = tz.localize(publishAt).isoformat()
+        publishAt = convert_youtube_date(publishAt)
         body['status']['publishAt'] = str(publishAt)
 
+    # Set originalDate except if the user force no originalDate
+    if options.get('--originalDate'):
+        originalDate = convert_youtube_date(options.get('--originalDate'))
+        body['recordingDetails']['recordingDate'] = str(originalDate)
+
     if options.get('--playlist'):
         playlist_id = get_playlist_by_name(youtube, options.get('--playlist'))
         if not playlist_id and options.get('--playlistCreate'):
